Report

# Report example

## Table of contents

### Part one

### Part two

## Big title on left page, with text on columns

### This is a little subtitle, here to explain what we are talking about

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam volutpat faucibus vestibulum. Mauris varius orci quam. Nam dui mauris, dictum at elementum at, mollis pulvinar est. Nunc lobortis pharetra erat, id rutrum lorem malesuada in.

Phasellus id nisl nec arcu tempor ultricies non id tortor. Mauris ex nibh, viverra vitae nisi eget, placerat pharetra est. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed id maximus diam. Cras molestie nisl vitae iaculis convallis. Vivamus molestie vitae nisl sed interdum. Nunc aliquam massa rhoncus finibus convallis. Vivamus sed vulputate risus. Nunc dignissim magna velit, quis lobortis ex volutpat eget. Proin dictum mauris condimentum consequat faucibus.

Duis maximus mauris ac purus eleifend, sit amet blandit nulla lacinia. Maecenas massa dolor, suscipit at erat eget, maximus dignissim dolor. Praesent consectetur maximus libero, eu facilisis ligula finibus et. Cras rhoncus eros sit amet lorem auctor, a efficitur leo tincidunt. Sed viverra interdum odio, eget pulvinar tortor blandit lacinia. Praesent consequat congue commodo. Phasellus eu massa feugiat, imperdiet nisi a, sagittis ipsum.

Suspendisse et gravida nunc. Quisque at felis nisl. Nam eget efficitur nunc. Vivamus fermentum imperdiet massa, porttitor elementum mauris faucibus scelerisque. Pellentesque ut metus tortor. Fusce vulputate ex at turpis consectetur, in vestibulum odio placerat. Suspendisse tempor sapien rutrum, cursus sem a, tincidunt odio. Sed in consequat augue. Proin finibus felis neque, ac hendrerit lorem consequat nec.

Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Fusce quam mi, dapibus et augue sit amet, porttitor volutpat orci. Vestibulum ac ligula at justo placerat pulvinar vel non velit. Duis vel iaculis nibh, non tristique lectus. Phasellus vel ex bibendum, accumsan tellus a, commodo nisi.

Mauris tincidunt dolor ligula, et egestas lectus rutrum consectetur. Donec ac ex mollis, vestibulum libero in, convallis risus.

## This is another big title, on a page full of work presentation

### We present you some of WeasyPrint's features.

#### Table of contents

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi mi ante, tincidunt quis vehicula sed, vehicula sed augue. Cras eget ante turpis.

#### Heading titles and page counters

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi mi ante, tincidunt quis vehicula sed, vehicula sed augue. Cras eget ante turpis.

#### Multi-column text

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi mi ante, tincidunt quis vehicula sed, vehicula sed augue. Cras eget ante turpis.

#### Internal links

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi mi ante, tincidunt quis vehicula sed, vehicula sed augue. Cras eget ante turpis.

#### Different page types

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi mi ante, tincidunt quis vehicula sed, vehicula sed augue. Cras eget ante turpis.

## Big title on the first right page

#### Offer #1

€135

- Lorem ipsum dolor sit amet.
- Nullam at diam eget urna consequat.
- Sed fringilla quam at augue semper aliquam.
- Cras nec lacus eu turpis finibus vulputate.

#### Offer #2

€175

- Lorem ipsum dolor sit amet.
- Nullam at diam eget urna consequat.
- Sed fringilla quam at augue semper aliquam.
- Mauris viverra nulla vel semper mollis.
- Nulla quis massa eu urna suscipit vehicula.
- Curabitur a odio id risus pharetra iaculis.

#### Offer #3

€200

- Lorem ipsum dolor sit amet.
- Nullam at diam eget urna consequat.
- Sed fringilla quam at augue semper aliquam.
- Mauris viverra nulla vel semper mollis.
- Cras nec lacus eu turpis finibus vulputate.
- Nulla quis massa eu urna suscipit vehicula.
- Curabitur a odio id risus pharetra iaculis.
- Mauris viverra nulla vel semper mollis.
- Lorem ipsum dolor sit amet, consectetur adipiscing elit.

## This is a chapter of a new section

## About some typography features

#### Italic and Bold Text

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut pulvinar dolor ac orci finibus elementum. Praesent sit amet ligula turpis.

#### Small Caps Text

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut pulvinar dolor ac orci finibus elementum.

#### Ligatures

Classical
  Offer → Offer
Discretionary
  Often → Often
Contextual
  #& → #&

#### Numbers

Fractions
  421/42 → 421/42
Ordinals
  2a 3o → 2a 3o
Slashed zero
  1000 → 1000
Superscript
  a2 → a2
Subscript
  C8H10N4O2 → C8H10N4O2

#### Figures

Lining
  - 409,280
  - 367,112
Old-Style
  - 409,280
  - 367,112
Tabular
  - 409,280
  - 367,112
Old & Tab.
  - 409,280
  - 367,112